class AppDomain(MarshalByRefObject,_AppDomain,IEvidenceFactory):
 """ Represents an application domain,which is an isolated environment where applications execute. This class cannot be inherited. """
 def AppendPrivatePath(self,path):
  """
  AppendPrivatePath(self: AppDomain,path: str)

   Appends the specified directory name to the private path list.

  

   path: The name of the directory to be appended to the private path.
  """
  pass
 def ApplyPolicy(self,assemblyName):
  """
  ApplyPolicy(self: AppDomain,assemblyName: str) -> str

  

   Returns the assembly display name after policy has been applied.

  

   assemblyName: The assembly display name,in the form provided by the System.Reflection.Assembly.FullName 

    property.

  

   Returns: A string containing the assembly display name after policy has been applied.
  """
  pass
 def ClearPrivatePath(self):
  """
  ClearPrivatePath(self: AppDomain)

   Resets the path that specifies the location of private assemblies to the empty string ("").
  """
  pass
 def ClearShadowCopyPath(self):
  """
  ClearShadowCopyPath(self: AppDomain)

   Resets the list of directories containing shadow copied assemblies to the empty string ("").
  """
  pass
 def CreateComInstanceFrom(self,*__args):
  """
  CreateComInstanceFrom(self: AppDomain,assemblyFile: str,typeName: str,hashValue: Array[Byte],hashAlgorithm: AssemblyHashAlgorithm) -> ObjectHandle

  

   Creates a new instance of a specified COM type. Parameters specify the name of a file that 

    contains an assembly containing the type and the name of the type.

  

  

   assemblyFile: The name of a file containing an assembly that defines the requested type.

   typeName: The name of the requested type.

   hashValue: Represents the value of the computed hash code.

   hashAlgorithm: Represents the hash algorithm used by the assembly manifest.

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.

  

  CreateComInstanceFrom(self: AppDomain,assemblyName: str,typeName: str) -> ObjectHandle

  

   Creates a new instance of a specified COM type. Parameters specify the name of a file that 

    contains an assembly containing the type and the name of the type.

  

  

   assemblyName: The name of a file containing an assembly that defines the requested type.

   typeName: The name of the requested type.

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.
  """
  pass
 @staticmethod
 def CreateDomain(friendlyName,securityInfo=None,*__args):
  """
  CreateDomain(friendlyName: str,securityInfo: Evidence,info: AppDomainSetup) -> AppDomain

  

   Creates a new application domain using the specified name,evidence,and application domain 

    setup information.

  

  

   friendlyName: The friendly name of the domain. This friendly name can be displayed in user interfaces to 

    identify the domain. For more information,see System.AppDomain.FriendlyName.

  

   securityInfo: Evidence that establishes the identity of the code that runs in the application domain. Pass 

    null to use the evidence of the current application domain.

  

   info: An object that contains application domain initialization information.

   Returns: The newly created application domain.

  CreateDomain(friendlyName: str,securityInfo: Evidence,info: AppDomainSetup,grantSet: PermissionSet,*fullTrustAssemblies: Array[StrongName]) -> AppDomain

  

   Creates a new application domain using the specified name,evidence,application domain setup 

    information,default permission set,and array of fully trusted assemblies.

  

  

   friendlyName: The friendly name of the domain. This friendly name can be displayed in user interfaces to 

    identify the domain. For more information,see the description of System.AppDomain.FriendlyName.

  

   securityInfo: Evidence that establishes the identity of the code that runs in the application domain. Pass 

    null to use the evidence of the current application domain.

  

   info: An object that contains application domain initialization information.

   grantSet: A default permission set that is granted to all assemblies loaded into the new application 

    domain that do not have specific grants.

  

   fullTrustAssemblies: An array of strong names representing assemblies to be considered fully trusted in the new 

    application domain.

  

   Returns: The newly created application domain.

  CreateDomain(friendlyName: str,securityInfo: Evidence,appBasePath: str,appRelativeSearchPath: str,shadowCopyFiles: bool,adInit: AppDomainInitializer,adInitArgs: Array[str]) -> AppDomain

  

   Creates a new application domain with the given name,using evidence,application base path,

    relative search path,and a parameter that specifies whether a shadow copy of an assembly is to 

    be loaded into the application domain. Specifies a callback method that is invoked when the 

    application domain is initialized,and an array of string arguments to pass the callback method.

  

  

   friendlyName: The friendly name of the domain. This friendly name can be displayed in user interfaces to 

    identify the domain. For more information,see System.AppDomain.FriendlyName.

  

   securityInfo: Evidence that establishes the identity of the code that runs in the application domain. Pass 

    null to use the evidence of the current application domain.

  

   appBasePath: The base directory that the assembly resolver uses to probe for assemblies. For more 

    information,see System.AppDomain.BaseDirectory.

  

   appRelativeSearchPath: The path relative to the base directory where the assembly resolver should probe for private 

    assemblies. For more information,see System.AppDomain.RelativeSearchPath.

  

   shadowCopyFiles: true to load a shadow copy of an assembly into the application domain.

   adInit: An System.AppDomainInitializer delegate that represents a callback method to invoke when the new 

    System.AppDomain object is initialized.

  

   adInitArgs: An array of string arguments to be passed to the callback represented by adInit,when the new 

    System.AppDomain object is initialized.

  

   Returns: The newly created application domain.

  CreateDomain(friendlyName: str,securityInfo: Evidence) -> AppDomain

  

   Creates a new application domain with the given name using the supplied evidence.

  

   friendlyName: The friendly name of the domain. This friendly name can be displayed in user interfaces to 

    identify the domain. For more information,see System.AppDomain.FriendlyName.

  

   securityInfo: Evidence that establishes the identity of the code that runs in the application domain. Pass 

    null to use the evidence of the current application domain.

  

   Returns: The newly created application domain.

  CreateDomain(friendlyName: str,securityInfo: Evidence,appBasePath: str,appRelativeSearchPath: str,shadowCopyFiles: bool) -> AppDomain

  

   Creates a new application domain with the given name,using evidence,application base path,

    relative search path,and a parameter that specifies whether a shadow copy of an assembly is to 

    be loaded into the application domain.

  

  

   friendlyName: The friendly name of the domain. This friendly name can be displayed in user interfaces to 

    identify the domain. For more information,see System.AppDomain.FriendlyName.

  

   securityInfo: Evidence that establishes the identity of the code that runs in the application domain. Pass 

    null to use the evidence of the current application domain.

  

   appBasePath: The base directory that the assembly resolver uses to probe for assemblies. For more 

    information,see System.AppDomain.BaseDirectory.

  

   appRelativeSearchPath: The path relative to the base directory where the assembly resolver should probe for private 

    assemblies. For more information,see System.AppDomain.RelativeSearchPath.

  

   shadowCopyFiles: If true,a shadow copy of an assembly is loaded into this application domain.

   Returns: The newly created application domain.

  CreateDomain(friendlyName: str) -> AppDomain

  

   Creates a new application domain with the specified name.

  

   friendlyName: The friendly name of the domain.

   Returns: The newly created application domain.
  """
  pass
 def CreateInstance(self,assemblyName,typeName,*__args):
  """
  CreateInstance(self: AppDomain,assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityAttributes: Evidence) -> ObjectHandle

  

   Creates a new instance of the specified type defined in the specified assembly. Parameters 

    specify a binder,binding flags,constructor arguments,culture-specific information used to 

    interpret arguments,activation attributes,and authorization to create the type.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects using reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityAttributes: Information used to authorize creation of typeName.

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.

  

  CreateInstance(self: AppDomain,assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates a new instance of the specified type defined in the specified assembly. Parameters 

    specify a binder,binding flags,constructor arguments,culture-specific information used to 

    interpret arguments,and optional activation attributes.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects using reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.

  

  CreateInstance(self: AppDomain,assemblyName: str,typeName: str) -> ObjectHandle

  

   Creates a new instance of the specified type defined in the specified assembly.

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.

  

  CreateInstance(self: AppDomain,assemblyName: str,typeName: str,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates a new instance of the specified type defined in the specified assembly. A parameter 

    specifies an array of activation attributes.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.
  """
  pass
 def CreateInstanceAndUnwrap(self,assemblyName,typeName,*__args):
  """
  CreateInstanceAndUnwrap(self: AppDomain,assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityAttributes: Evidence) -> object

  

   Creates a new instance of the specified type. Parameters specify the name of the type,and how 

    it is found and created.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects using reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: A culture-specific object used to govern the coercion of types. If culture is null,the 

    CultureInfo for the current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityAttributes: Information used to authorize creation of typeName.

   Returns: An instance of the object specified by typeName.

  CreateInstanceAndUnwrap(self: AppDomain,assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> object

  

   Creates a new instance of the specified type defined in the specified assembly,specifying 

    whether the case of the type name is ignored; the binding attributes and the binder that are 

    used to select the type to be created; the arguments of the constructor; the culture; and the 

    activation attributes.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects using reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: A culture-specific object used to govern the coercion of types. If culture is null,the 

    CultureInfo for the current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: An instance of the object specified by typeName.

  CreateInstanceAndUnwrap(self: AppDomain,assemblyName: str,typeName: str) -> object

  

   Creates a new instance of the specified type. Parameters specify the assembly where the type is 

    defined,and the name of the type.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   Returns: An instance of the object specified by typeName.

  CreateInstanceAndUnwrap(self: AppDomain,assemblyName: str,typeName: str,activationAttributes: Array[object]) -> object

  

   Creates a new instance of the specified type. Parameters specify the assembly where the type is 

    defined,the name of the type,and an array of activation attributes.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: An instance of the object specified by typeName.
  """
  pass
 def CreateInstanceFrom(self,assemblyFile,typeName,*__args):
  """
  CreateInstanceFrom(self: AppDomain,assemblyFile: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityAttributes: Evidence) -> ObjectHandle

  

   Creates a new instance of the specified type defined in the specified assembly file.

  

   assemblyFile: The name,including the path,of a file that contains an assembly that defines the requested 

    type. The assembly is loaded using the System.Reflection.Assembly.LoadFrom(System.String)  

    method.

  

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects through reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityAttributes: Information used to authorize creation of typeName.

   Returns: An object that is a wrapper for the new instance,or null if typeName is not found. The return 

    value needs to be unwrapped to access the real object.

  

  CreateInstanceFrom(self: AppDomain,assemblyFile: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates a new instance of the specified type defined in the specified assembly file.

  

   assemblyFile: The name,including the path,of a file that contains an assembly that defines the requested 

    type. The assembly is loaded using the System.Reflection.Assembly.LoadFrom(System.String)  

    method.

  

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects through reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: An object that is a wrapper for the new instance,or null if typeName is not found. The return 

    value needs to be unwrapped to access the real object.

  

  CreateInstanceFrom(self: AppDomain,assemblyFile: str,typeName: str) -> ObjectHandle

  

   Creates a new instance of the specified type defined in the specified assembly file.

  

   assemblyFile: The name,including the path,of a file that contains an assembly that defines the requested 

    type. The assembly is loaded using the System.Reflection.Assembly.LoadFrom(System.String)  

    method.

  

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   Returns: An object that is a wrapper for the new instance,or null if typeName is not found. The return 

    value needs to be unwrapped to access the real object.

  

  CreateInstanceFrom(self: AppDomain,assemblyFile: str,typeName: str,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates a new instance of the specified type defined in the specified assembly file.

  

   assemblyFile: The name,including the path,of a file that contains an assembly that defines the requested 

    type. The assembly is loaded using the System.Reflection.Assembly.LoadFrom(System.String)  

    method.

  

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: An object that is a wrapper for the new instance,or null if typeName is not found. The return 

    value needs to be unwrapped to access the real object.
  """
  pass
 def CreateInstanceFromAndUnwrap(self,*__args):
  """
  CreateInstanceFromAndUnwrap(self: AppDomain,assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityAttributes: Evidence) -> object

  

   Creates a new instance of the specified type defined in the specified assembly file.

  

   assemblyName: The file name and path of the assembly that defines the requested type.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects through reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityAttributes: Information used to authorize creation of typeName.

   Returns: The requested object,or null if typeName is not found.

  CreateInstanceFromAndUnwrap(self: AppDomain,assemblyFile: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> object

  

   Creates a new instance of the specified type defined in the specified assembly file,specifying 

    whether the case of the type name is ignored; the binding attributes and the binder that are 

    used to select the type to be created; the arguments of the constructor; the culture; and the 

    activation attributes.

  

  

   assemblyFile: The file name and path of the assembly that defines the requested type.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects through reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: The requested object,or null if typeName is not found.

  CreateInstanceFromAndUnwrap(self: AppDomain,assemblyName: str,typeName: str) -> object

  

   Creates a new instance of the specified type defined in the specified assembly file.

  

   assemblyName: The file name and path of the assembly that defines the requested type.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   Returns: The requested object,or null if typeName is not found.

  CreateInstanceFromAndUnwrap(self: AppDomain,assemblyName: str,typeName: str,activationAttributes: Array[object]) -> object

  

   Creates a new instance of the specified type defined in the specified assembly file.

  

   assemblyName: The file name and path of the assembly that defines the requested type.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly 

    (see the System.Type.FullName property).

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: The requested object,or null if typeName is not found.
  """
  pass
 def DefineDynamicAssembly(self,name,access,*__args):
  """
  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,evidence: Evidence,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet) -> AssemblyBuilder

  

   Defines a dynamic assembly using the specified name,access mode,storage directory,evidence,

    and permission requests.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the assembly will be saved. If dir is null,the directory 

    defaults to the current directory.

  

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   Returns: A dynamic assembly with the specified name and features.

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,evidence: Evidence,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet) -> AssemblyBuilder

  

   Defines a dynamic assembly using the specified name,access mode,evidence,and permission 

    requests.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   Returns: A dynamic assembly with the specified name and features.

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet) -> AssemblyBuilder

  

   Defines a dynamic assembly using the specified name,access mode,storage directory,and 

    permission requests.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the assembly will be saved. If dir is null,the directory 

    defaults to the current directory.

  

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   Returns: A dynamic assembly with the specified name and features.

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,isSynchronized: bool,assemblyAttributes: IEnumerable[CustomAttributeBuilder]) -> AssemblyBuilder

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,evidence: Evidence,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet,isSynchronized: bool,assemblyAttributes: IEnumerable[CustomAttributeBuilder]) -> AssemblyBuilder

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,evidence: Evidence,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet,isSynchronized: bool) -> AssemblyBuilder

  

   Defines a dynamic assembly using the specified name,access mode,storage directory,evidence,

    permission requests,and synchronization option.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the dynamic assembly will be saved. If dir is null,the 

    directory defaults to the current directory.

  

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   isSynchronized: true to synchronize the creation of modules,types,and members in the dynamic assembly; 

    otherwise,false.

  

   Returns: A dynamic assembly with the specified name and features.

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,evidence: Evidence) -> AssemblyBuilder

  

   Defines a dynamic assembly using the specified name,access mode,storage directory,and 

    evidence.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the assembly will be saved. If dir is null,the directory 

    defaults to the current directory.

  

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   Returns: A dynamic assembly with the specified name and features.

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,assemblyAttributes: IEnumerable[CustomAttributeBuilder],securityContextSource: SecurityContextSource) -> AssemblyBuilder

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,assemblyAttributes: IEnumerable[CustomAttributeBuilder]) -> AssemblyBuilder

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess) -> AssemblyBuilder

  

   Defines a dynamic assembly with the specified name and access mode.

  

   name: The unique identity of the dynamic assembly.

   access: The access mode for the dynamic assembly.

   Returns: A dynamic assembly with the specified name and access mode.

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet) -> AssemblyBuilder

  

   Defines a dynamic assembly using the specified name,access mode,and permission requests.

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   Returns: A dynamic assembly with the specified name and features.

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,evidence: Evidence) -> AssemblyBuilder

  

   Defines a dynamic assembly using the specified name,access mode,and evidence.

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   Returns: A dynamic assembly with the specified name and features.

  DefineDynamicAssembly(self: AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str) -> AssemblyBuilder

  

   Defines a dynamic assembly using the specified name,access mode,and storage directory.

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the assembly will be saved. If dir is null,the directory 

    defaults to the current directory.

  

   Returns: A dynamic assembly with the specified name and features.
  """
  pass
 def DoCallBack(self,callBackDelegate):
  """
  DoCallBack(self: AppDomain,callBackDelegate: CrossAppDomainDelegate)

   Executes the code in another application domain that is identified by the specified delegate.

  

   callBackDelegate: A delegate that specifies a method to call.
  """
  pass
 def ExecuteAssembly(self,assemblyFile,*__args):
  """
  ExecuteAssembly(self: AppDomain,assemblyFile: str,args: Array[str]) -> int

  

   Executes the assembly contained in the specified file,using the specified arguments.

  

   assemblyFile: The name of the file that contains the assembly to execute.

   args: The arguments to the entry point of the assembly.

   Returns: The value that is returned by the entry point of the assembly.

  ExecuteAssembly(self: AppDomain,assemblyFile: str,assemblySecurity: Evidence,args: Array[str],hashValue: Array[Byte],hashAlgorithm: AssemblyHashAlgorithm) -> int

  

   Executes the assembly contained in the specified file,using the specified evidence,arguments,

    hash value,and hash algorithm.

  

  

   assemblyFile: The name of the file that contains the assembly to execute.

   assemblySecurity: The supplied evidence for the assembly.

   args: The arguments to the entry point of the assembly.

   hashValue: Represents the value of the computed hash code.

   hashAlgorithm: Represents the hash algorithm used by the assembly manifest.

   Returns: The value returned by the entry point of the assembly.

  ExecuteAssembly(self: AppDomain,assemblyFile: str,args: Array[str],hashValue: Array[Byte],hashAlgorithm: AssemblyHashAlgorithm) -> int

  

   Executes the assembly contained in the specified file,using the specified arguments,hash 

    value,and hash algorithm.

  

  

   assemblyFile: The name of the file that contains the assembly to execute.

   args: The arguments to the entry point of the assembly.

   hashValue: Represents the value of the computed hash code.

   hashAlgorithm: Represents the hash algorithm used by the assembly manifest.

   Returns: The value that is returned by the entry point of the assembly.

  ExecuteAssembly(self: AppDomain,assemblyFile: str) -> int

  

   Executes the assembly contained in the specified file.

  

   assemblyFile: The name of the file that contains the assembly to execute.

   Returns: The value returned by the entry point of the assembly.

  ExecuteAssembly(self: AppDomain,assemblyFile: str,assemblySecurity: Evidence) -> int

  

   Executes the assembly contained in the specified file,using the specified evidence.

  

   assemblyFile: The name of the file that contains the assembly to execute.

   assemblySecurity: Evidence for loading the assembly.

   Returns: The value returned by the entry point of the assembly.

  ExecuteAssembly(self: AppDomain,assemblyFile: str,assemblySecurity: Evidence,args: Array[str]) -> int

  

   Executes the assembly contained in the specified file,using the specified evidence and 

    arguments.

  

  

   assemblyFile: The name of the file that contains the assembly to execute.

   assemblySecurity: The supplied evidence for the assembly.

   args: The arguments to the entry point of the assembly.

   Returns: The value returned by the entry point of the assembly.
  """
  pass
 def ExecuteAssemblyByName(self,assemblyName,*__args):
  """
  ExecuteAssemblyByName(self: AppDomain,assemblyName: str,*args: Array[str]) -> int

  

   Executes the assembly given its display name,using the specified arguments.

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   args: Command-line arguments to pass when starting the process.

   Returns: The value that is returned by the entry point of the assembly.

  ExecuteAssemblyByName(self: AppDomain,assemblyName: AssemblyName,assemblySecurity: Evidence,*args: Array[str]) -> int

  

   Executes the assembly given an System.Reflection.AssemblyName,using the specified evidence and 

    arguments.

  

  

   assemblyName: An System.Reflection.AssemblyName object representing the name of the assembly.

   assemblySecurity: Evidence for loading the assembly.

   args: Command-line arguments to pass when starting the process.

   Returns: The value returned by the entry point of the assembly.

  ExecuteAssemblyByName(self: AppDomain,assemblyName: AssemblyName,*args: Array[str]) -> int

  

   Executes the assembly given an System.Reflection.AssemblyName,using the specified arguments.

  

   assemblyName: An System.Reflection.AssemblyName object representing the name of the assembly.

   args: Command-line arguments to pass when starting the process.

   Returns: The value that is returned by the entry point of the assembly.

  ExecuteAssemblyByName(self: AppDomain,assemblyName: str) -> int

  

   Executes an assembly given its display name.

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   Returns: The value returned by the entry point of the assembly.

  ExecuteAssemblyByName(self: AppDomain,assemblyName: str,assemblySecurity: Evidence) -> int

  

   Executes an assembly given its display name,using the specified evidence.

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   assemblySecurity: Evidence for loading the assembly.

   Returns: The value returned by the entry point of the assembly.

  ExecuteAssemblyByName(self: AppDomain,assemblyName: str,assemblySecurity: Evidence,*args: Array[str]) -> int

  

   Executes the assembly given its display name,using the specified evidence and arguments.

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   assemblySecurity: Evidence for loading the assembly.

   args: Command-line arguments to pass when starting the process.

   Returns: The value returned by the entry point of the assembly.
  """
  pass
 def GetAssemblies(self):
  """
  GetAssemblies(self: AppDomain) -> Array[Assembly]

  

   Gets the assemblies that have been loaded into the execution context of this application domain.

   Returns: An array of assemblies in this application domain.
  """
  pass
 @staticmethod
 def GetCurrentThreadId():
  """
  GetCurrentThreadId() -> int

  

   Gets the current thread identifier.

   Returns: A 32-bit signed integer that is the identifier of the current thread.
  """
  pass
 def GetData(self,name):
  """
  GetData(self: AppDomain,name: str) -> object

  

   Gets the value stored in the current application domain for the specified name.

  

   name: The name of a predefined application domain property,or the name of an application domain 

    property you have defined.

  

   Returns: The value of the name property,or null if the property does not exist.
  """
  pass
 def GetType(self):
  """
  GetType(self: AppDomain) -> Type

  

   Gets the type of the current instance.

   Returns: The type of the current instance.
  """
  pass
 def InitializeLifetimeService(self):
  """
  InitializeLifetimeService(self: AppDomain) -> object

  

   Gives the System.AppDomain an infinite lifetime by preventing a lease from being created.

   Returns: Always null.
  """
  pass
 def IsCompatibilitySwitchSet(self,value):
  """
  IsCompatibilitySwitchSet(self: AppDomain,value: str) -> Nullable[bool]

  

   Gets a nullable Boolean value that indicates whether any compatibility switches are set,and if 

    so,whether the specified compatibility switch is set.

  

  

   value: The compatibility switch to test.

   Returns: A null reference (Nothing in Visual Basic) if no compatibility switches are set; otherwise,a 

    Boolean value that indicates whether the compatibility switch that is specified by value is set.
  """
  pass
 def IsDefaultAppDomain(self):
  """
  IsDefaultAppDomain(self: AppDomain) -> bool

  

   Returns a value that indicates whether the application domain is the default application domain 

    for the process.

  

   Returns: true if the current System.AppDomain object represents the default application domain for the 

    process; otherwise,false.
  """
  pass
 def IsFinalizingForUnload(self):
  """
  IsFinalizingForUnload(self: AppDomain) -> bool

  

   Indicates whether this application domain is unloading,and the objects it contains are being 

    finalized by the common language runtime.

  

   Returns: true if this application domain is unloading and the common language runtime has started 

    invoking finalizers; otherwise,false.
  """
  pass
 def Load(self,*__args):
  """
  Load(self: AppDomain,rawAssembly: Array[Byte],rawSymbolStore: Array[Byte],securityEvidence: Evidence) -> Assembly

  

   Loads the System.Reflection.Assembly with a common object file format (COFF) based image 

    containing an emitted System.Reflection.Assembly. The raw bytes representing the symbols for the 

    System.Reflection.Assembly are also loaded.

  

  

   rawAssembly: An array of type byte that is a COFF-based image containing an emitted assembly.

   rawSymbolStore: An array of type byte containing the raw bytes representing the symbols for the assembly.

   securityEvidence: Evidence for loading the assembly.

   Returns: The loaded assembly.

  Load(self: AppDomain,assemblyRef: AssemblyName,assemblySecurity: Evidence) -> Assembly

  

   Loads an System.Reflection.Assembly given its System.Reflection.AssemblyName.

  

   assemblyRef: An object that describes the assembly to load.

   assemblySecurity: Evidence for loading the assembly.

   Returns: The loaded assembly.

  Load(self: AppDomain,assemblyString: str,assemblySecurity: Evidence) -> Assembly

  

   Loads an System.Reflection.Assembly given its display name.

  

   assemblyString: The display name of the assembly. See System.Reflection.Assembly.FullName.

   assemblySecurity: Evidence for loading the assembly.

   Returns: The loaded assembly.

  Load(self: AppDomain,rawAssembly: Array[Byte],rawSymbolStore: Array[Byte]) -> Assembly

  

   Loads the System.Reflection.Assembly with a common object file format (COFF) based image 

    containing an emitted System.Reflection.Assembly. The raw bytes representing the symbols for the 

    System.Reflection.Assembly are also loaded.

  

  

   rawAssembly: An array of type byte that is a COFF-based image containing an emitted assembly.

   rawSymbolStore: An array of type byte containing the raw bytes representing the symbols for the assembly.

   Returns: The loaded assembly.

  Load(self: AppDomain,assemblyRef: AssemblyName) -> Assembly

  

   Loads an System.Reflection.Assembly given its System.Reflection.AssemblyName.

  

   assemblyRef: An object that describes the assembly to load.

   Returns: The loaded assembly.

  Load(self: AppDomain,assemblyString: str) -> Assembly

  

   Loads an System.Reflection.Assembly given its display name.

  

   assemblyString: The display name of the assembly. See System.Reflection.Assembly.FullName.

   Returns: The loaded assembly.

  Load(self: AppDomain,rawAssembly: Array[Byte]) -> Assembly

  

   Loads the System.Reflection.Assembly with a common object file format (COFF) based image 

    containing an emitted System.Reflection.Assembly.

  

  

   rawAssembly: An array of type byte that is a COFF-based image containing an emitted assembly.

   Returns: The loaded assembly.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ReflectionOnlyGetAssemblies(self):
  """
  ReflectionOnlyGetAssemblies(self: AppDomain) -> Array[Assembly]

  

   Returns the assemblies that have been loaded into the reflection-only context of the application 

    domain.

  

   Returns: An array of System.Reflection.Assembly objects that represent the assemblies loaded into the 

    reflection-only context of the application domain.
  """
  pass
 def SetAppDomainPolicy(self,domainPolicy):
  """
  SetAppDomainPolicy(self: AppDomain,domainPolicy: PolicyLevel)

   Establishes the security policy level for this application domain.

  

   domainPolicy: The security policy level.
  """
  pass
 def SetCachePath(self,path):
  """
  SetCachePath(self: AppDomain,path: str)

   Establishes the specified directory path as the location where assemblies are shadow copied.

  

   path: The fully qualified path to the shadow copy location.
  """
  pass
 def SetData(self,name,data,permission=None):
  """
  SetData(self: AppDomain,name: str,data: object,permission: IPermission)

   Assigns the specified value to the specified application domain property,with a specified 

    permission to demand of the caller when the property is retrieved.

  

  

   name: The name of a user-defined application domain property to create or change.

   data: The value of the property.

   permission: The permission to demand of the caller when the property is retrieved.

  SetData(self: AppDomain,name: str,data: object)

   Assigns the specified value to the specified application domain property.

  

   name: The name of a user-defined application domain property to create or change.

   data: The value of the property.
  """
  pass
 def SetDynamicBase(self,path):
  """
  SetDynamicBase(self: AppDomain,path: str)

   Establishes the specified directory path as the base directory for subdirectories where 

    dynamically generated files are stored and accessed.

  

  

   path: The fully qualified path that is the base directory for subdirectories where dynamic assemblies 

    are stored.
  """
  pass
 def SetPrincipalPolicy(self,policy):
  """
  SetPrincipalPolicy(self: AppDomain,policy: PrincipalPolicy)

   Specifies how principal and identity objects should be attached to a thread if the thread 

    attempts to bind to a principal while executing in this application domain.

  

  

   policy: One of the System.Security.Principal.PrincipalPolicy values that specifies the type of the 

    principal object to attach to threads.
  """
  pass
 def SetShadowCopyFiles(self):
  """
  SetShadowCopyFiles(self: AppDomain)

   Turns on shadow copying.
  """
  pass
 def SetShadowCopyPath(self,path):
  """
  SetShadowCopyPath(self: AppDomain,path: str)

   Establishes the specified directory path as the location of assemblies to be shadow copied.

  

   path: A list of directory names,where each name is separated by a semicolon.
  """
  pass
 def SetThreadPrincipal(self,principal):
  """
  SetThreadPrincipal(self: AppDomain,principal: IPrincipal)

   Sets the default principal object to be attached to threads if they attempt to bind to a 

    principal while executing in this application domain.

  

  

   principal: The principal object to attach to threads.
  """
  pass
 def ToString(self):
  """
  ToString(self: AppDomain) -> str

  

   Obtains a string representation that includes the friendly name of the application domain and 

    any context policies.

  

   Returns: A string formed by concatenating the literal string "Name:",the friendly name of the 

    application domain,and either string representations of the context policies or the string 

    "There are no context policies."
  """
  pass
 @staticmethod
 def Unload(domain):
  """
  Unload(domain: AppDomain)

   Unloads the specified application domain.

  

   domain: An application domain to unload.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 ActivationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the activation context for the current application domain.



Get: ActivationContext(self: AppDomain) -> ActivationContext



"""

 ApplicationIdentity=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the identity of the application in the application domain.



Get: ApplicationIdentity(self: AppDomain) -> ApplicationIdentity



"""

 ApplicationTrust=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets information describing permissions granted to an application and whether the application has a trust level that allows it to run.



Get: ApplicationTrust(self: AppDomain) -> ApplicationTrust



"""

 BaseDirectory=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the base directory that the assembly resolver uses to probe for assemblies.



Get: BaseDirectory(self: AppDomain) -> str



"""

 DomainManager=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the domain manager that was provided by the host when the application domain was initialized.



Get: DomainManager(self: AppDomain) -> AppDomainManager



"""

 DynamicDirectory=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the directory that the assembly resolver uses to probe for dynamically created assemblies.



Get: DynamicDirectory(self: AppDomain) -> str



"""

 Evidence=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Security.Policy.Evidence associated with this application domain.



Get: Evidence(self: AppDomain) -> Evidence



"""

 FriendlyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the friendly name of this application domain.



Get: FriendlyName(self: AppDomain) -> str



"""

 Id=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an integer that uniquely identifies the application domain within the process.



Get: Id(self: AppDomain) -> int



"""

 IsFullyTrusted=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether assemblies that are loaded into the current application domain execute with full trust.



Get: IsFullyTrusted(self: AppDomain) -> bool



"""

 IsHomogenous=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the current application domain has a set of permissions that is granted to all assemblies that are loaded into the application domain.



Get: IsHomogenous(self: AppDomain) -> bool



"""

 MonitoringSurvivedMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of bytes that survived the last full,blocking collection and that are known to be referenced by the current application domain.



Get: MonitoringSurvivedMemorySize(self: AppDomain) -> Int64



"""

 MonitoringTotalAllocatedMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total size,in bytes,of all memory allocations that have been made by the application domain since it was created,without subtracting memory that has been collected.



Get: MonitoringTotalAllocatedMemorySize(self: AppDomain) -> Int64



"""

 MonitoringTotalProcessorTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total processor time that has been used by all threads while executing in the current application domain,since the process started.



Get: MonitoringTotalProcessorTime(self: AppDomain) -> TimeSpan



"""

 PermissionSet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the permission set of a sandboxed application domain.



Get: PermissionSet(self: AppDomain) -> PermissionSet



"""

 RelativeSearchPath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the path under the base directory where the assembly resolver should probe for private assemblies.



Get: RelativeSearchPath(self: AppDomain) -> str



"""

 SetupInformation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the application domain configuration information for this instance.



Get: SetupInformation(self: AppDomain) -> AppDomainSetup



"""

 ShadowCopyFiles=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an indication whether the application domain is configured to shadow copy files.



Get: ShadowCopyFiles(self: AppDomain) -> bool



"""


 AssemblyLoad=None
 AssemblyResolve=None
 CurrentDomain=None
 DomainUnload=None
 FirstChanceException=None
 MonitoringIsEnabled=False
 ProcessExit=None
 ReflectionOnlyAssemblyResolve=None
 ResourceResolve=None
 TypeResolve=None
 UnhandledException=None




class RunInstallerAttribute(Attribute,_Attribute):
 """
 Specifies whether the Visual Studio Custom Action Installer or the Installutil.exe (Installer Tool) should be invoked when the assembly is installed.

 

 RunInstallerAttribute(runInstaller: bool)
 """
 def Equals(self,obj):
  """
  Equals(self: RunInstallerAttribute,obj: object) -> bool

  

   Determines whether the value of the specified System.ComponentModel.RunInstallerAttribute is 

    equivalent to the current System.ComponentModel.RunInstallerAttribute.

  

  

   obj: The object to compare.

   Returns: true if the specified System.ComponentModel.RunInstallerAttribute is equal to the current 

    System.ComponentModel.RunInstallerAttribute; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: RunInstallerAttribute) -> int

  

   Generates a hash code for the current System.ComponentModel.RunInstallerAttribute.

   Returns: A hash code for the current System.ComponentModel.RunInstallerAttribute.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: RunInstallerAttribute) -> bool

  

   Determines if this attribute is the default.

   Returns: true if the attribute is the default value for this attribute class; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,runInstaller):
  """ __new__(cls: type,runInstaller: bool) """
  pass
 def __ne__(self,*args):
  pass
 RunInstaller=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether an installer should be invoked during installation of an assembly.



Get: RunInstaller(self: RunInstallerAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class Clipboard(object):
 """ Provides methods to place data on and retrieve data from the system Clipboard. This class cannot be inherited. """
 @staticmethod
 def Clear():
  """
  Clear()

   Removes all data from the Clipboard.
  """
  pass
 @staticmethod
 def ContainsAudio():
  """
  ContainsAudio() -> bool

  

   Indicates whether there is data on the Clipboard in the 

    System.Windows.Forms.DataFormats.WaveAudio format.

  

   Returns: true if there is audio data on the Clipboard; otherwise,false.
  """
  pass
 @staticmethod
 def ContainsData(format):
  """
  ContainsData(format: str) -> bool

  

   Indicates whether there is data on the Clipboard that is in the specified format or can be 

    converted to that format.

  

  

   format: The format of the data to look for. See System.Windows.Forms.DataFormats for predefined formats.

   Returns: true if there is data on the Clipboard that is in the specified format or can be converted to 

    that format; otherwise,false.
  """
  pass
 @staticmethod
 def ContainsFileDropList():
  """
  ContainsFileDropList() -> bool

  

   Indicates whether there is data on the Clipboard that is in the 

    System.Windows.Forms.DataFormats.FileDrop format or can be converted to that format.

  

   Returns: true if there is a file drop list on the Clipboard; otherwise,false.
  """
  pass
 @staticmethod
 def ContainsImage():
  """
  ContainsImage() -> bool

  

   Indicates whether there is data on the Clipboard that is in the 

    System.Windows.Forms.DataFormats.Bitmap format or can be converted to that format.

  

   Returns: true if there is image data on the Clipboard; otherwise,false.
  """
  pass
 @staticmethod
 def ContainsText(format=None):
  """
  ContainsText(format: TextDataFormat) -> bool

  

   Indicates whether there is text data on the Clipboard in the format indicated by the specified 

    System.Windows.Forms.TextDataFormat value.

  

  

   format: One of the System.Windows.Forms.TextDataFormat values.

   Returns: true if there is text data on the Clipboard in the value specified for format; otherwise,false.

  ContainsText() -> bool

  

   Indicates whether there is data on the Clipboard in the System.Windows.Forms.TextDataFormat.Text 

    or System.Windows.Forms.TextDataFormat.UnicodeText format,depending on the operating system.

  

   Returns: true if there is text data on the Clipboard; otherwise,false.
  """
  pass
 @staticmethod
 def GetAudioStream():
  """
  GetAudioStream() -> Stream

  

   Retrieves an audio stream from the Clipboard.

   Returns: A System.IO.Stream containing audio data or null if the Clipboard does not contain any data in 

    the System.Windows.Forms.DataFormats.WaveAudio format.
  """
  pass
 @staticmethod
 def GetData(format):
  """
  GetData(format: str) -> object

  

   Retrieves data from the Clipboard in the specified format.

  

   format: The format of the data to retrieve. See System.Windows.Forms.DataFormats for predefined formats.

   Returns: An System.Object representing the Clipboard data or null if the Clipboard does not contain any 

    data that is in the specified format or can be converted to that format.
  """
  pass
 @staticmethod
 def GetDataObject():
  """
  GetDataObject() -> IDataObject

  

   Retrieves the data that is currently on the system Clipboard.

   Returns: An System.Windows.Forms.IDataObject that represents the data currently on the Clipboard,or null 

    if there is no data on the Clipboard.
  """
  pass
 @staticmethod
 def GetFileDropList():
  """
  GetFileDropList() -> StringCollection

  

   Retrieves a collection of file names from the Clipboard.

   Returns: A System.Collections.Specialized.StringCollection containing file names or null if the Clipboard 

    does not contain any data that is in the System.Windows.Forms.DataFormats.FileDrop format or can 

    be converted to that format.
  """
  pass
 @staticmethod
 def GetImage():
  """
  GetImage() -> Image

  

   Retrieves an image from the Clipboard.

   Returns: An System.Drawing.Image representing the Clipboard image data or null if the Clipboard does not 

    contain any data that is in the System.Windows.Forms.DataFormats.Bitmap format or can be 

    converted to that format.
  """
  pass
 @staticmethod
 def GetText(format=None):
  """
  GetText(format: TextDataFormat) -> str

  

   Retrieves text data from the Clipboard in the format indicated by the specified 

    System.Windows.Forms.TextDataFormat value.

  

  

   format: One of the System.Windows.Forms.TextDataFormat values.

   Returns: The Clipboard text data or System.String.Empty if the Clipboard does not contain data in the 

    specified format.

  

  GetText() -> str

  

   Retrieves text data from the Clipboard in the System.Windows.Forms.TextDataFormat.Text or 

    System.Windows.Forms.TextDataFormat.UnicodeText format,depending on the operating system.

  

   Returns: The Clipboard text data or System.String.Empty if the Clipboard does not contain data in the 

    System.Windows.Forms.TextDataFormat.Text or System.Windows.Forms.TextDataFormat.UnicodeText 

    format,depending on the operating system.
  """
  pass
 @staticmethod
 def SetAudio(*__args):
  """
  SetAudio(audioStream: Stream)

   Clears the Clipboard and then adds a System.IO.Stream in the 

    System.Windows.Forms.DataFormats.WaveAudio format.

  

  

   audioStream: A System.IO.Stream containing the audio data.

  SetAudio(audioBytes: Array[Byte])

   Clears the Clipboard and then adds a System.Byte array in the 

    System.Windows.Forms.DataFormats.WaveAudio format after converting it to a System.IO.Stream.

  

  

   audioBytes: A System.Byte array containing the audio data.
  """
  pass
 @staticmethod
 def SetData(format,data):
  """
  SetData(format: str,data: object)

   Clears the Clipboard and then adds data in the specified format.

  

   format: The format of the data to set. See System.Windows.Forms.DataFormats for predefined formats.

   data: An System.Object representing the data to add.
  """
  pass
 @staticmethod
 def SetDataObject(data,copy=None,retryTimes=None,retryDelay=None):
  """
  SetDataObject(data: object,copy: bool,retryTimes: int,retryDelay: int)

   Clears the Clipboard and then attempts to place data on it the specified number of times and 

    with the specified delay between attempts,optionally leaving the data on the Clipboard after 

    the application exits.

  

  

   data: The data to place on the Clipboard.

   copy: true if you want data to remain on the Clipboard after this application exits; otherwise,false.

   retryTimes: The number of times to attempt placing the data on the Clipboard.

   retryDelay: The number of milliseconds to pause between attempts.

  SetDataObject(data: object,copy: bool)

   Clears the Clipboard and then places data on it and specifies whether the data should remain 

    after the application exits.

  

  

   data: The data to place on the Clipboard.

   copy: true if you want data to remain on the Clipboard after this application exits; otherwise,false.

  SetDataObject(data: object)

   Clears the Clipboard and then places nonpersistent data on it.

  

   data: The data to place on the Clipboard.
  """
  pass
 @staticmethod
 def SetFileDropList(filePaths):
  """
  SetFileDropList(filePaths: StringCollection)

   Clears the Clipboard and then adds a collection of file names in the 

    System.Windows.Forms.DataFormats.FileDrop format.

  

  

   filePaths: A System.Collections.Specialized.StringCollection containing the file names.
  """
  pass
 @staticmethod
 def SetImage(image):
  """
  SetImage(image: Image)

   Clears the Clipboard and then adds an System.Drawing.Image in the 

    System.Windows.Forms.DataFormats.Bitmap format.

  

  

   image: The System.Drawing.Image to add to the Clipboard.
  """
  pass
 @staticmethod
 def SetText(text,format=None):
  """
  SetText(text: str,format: TextDataFormat)

   Clears the Clipboard and then adds text data in the format indicated by the specified 

    System.Windows.Forms.TextDataFormat value.

  

  

   text: The text to add to the Clipboard.

   format: One of the System.Windows.Forms.TextDataFormat values.

  SetText(text: str)

   Clears the Clipboard and then adds text data in the System.Windows.Forms.TextDataFormat.Text or 

    System.Windows.Forms.TextDataFormat.UnicodeText format,depending on the operating system.

  

  

   text: The text to add to the Clipboard.
  """
  pass



# encoding: utf-8
# module System.Windows.Threading calls itself Threading
# from WindowsBase,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# functions

def DispatcherOperation(*args,**kwargs): # real signature unknown
 """ Represents an object that is used to interact with an operation that has been posted to the System.Windows.Threading.Dispatcher queue. """
 pass
# classes

class Dispatcher(object):
 """ Provides services for managing the queue of work items for a thread. """
 def BeginInvoke(self,*__args):
  """
  BeginInvoke(self: Dispatcher,method: Delegate,*args: Array[object]) -> DispatcherOperation

  

   Executes the specified delegate asynchronously with the specified arguments on the thread that 

    the System.Windows.Threading.Dispatcher was created on.

  

  

   method: The delegate to a method that takes parameters specified in args,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   args: An array of objects to pass as arguments to the given method. Can be null.

   Returns: An object,which is returned immediately after 

    erload:System.Windows.Threading.Dispatcher.BeginInvoke is called,that can be used to interact 

    with the delegate as it is pending execution in the event queue.

  

  BeginInvoke(self: Dispatcher,method: Delegate,priority: DispatcherPriority,*args: Array[object]) -> DispatcherOperation

  

   Executes the specified delegate asynchronously with the specified arguments,at the specified 

    priority,on the thread that the System.Windows.Threading.Dispatcher was created on.

  

  

   method: The delegate to a method that takes parameters specified in args,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   args: An array of objects to pass as arguments to the given method. Can be null.

   Returns: An object,which is returned immediately after 

    erload:System.Windows.Threading.Dispatcher.BeginInvoke is called,that can be used to interact 

    with the delegate as it is pending execution in the event queue.

  

  BeginInvoke(self: Dispatcher,priority: DispatcherPriority,method: Delegate,arg: object,*args: Array[object]) -> DispatcherOperation

  

   Executes the specified delegate asynchronously at the specified priority and with the specified 

    array of arguments on the thread the System.Windows.Threading.Dispatcher is associated with.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   method: A delegate to a method that takes multiple arguments,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   arg: The object to pass as an argument to the specified method.

   args: An array of objects to pass as arguments to the specified method.

   Returns: An object,which is returned immediately after 

    erload:System.Windows.Threading.Dispatcher.BeginInvoke is called,that can be used to interact 

    with the delegate as it is pending execution in the System.Windows.Threading.Dispatcher queue.

  

  BeginInvoke(self: Dispatcher,priority: DispatcherPriority,method: Delegate) -> DispatcherOperation

  

   Executes the specified delegate asynchronously at the specified priority on the thread the 

    System.Windows.Threading.Dispatcher is associated with.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   method: The delegate to a method that takes no arguments,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   Returns: An object,which is returned immediately after 

    erload:System.Windows.Threading.Dispatcher.BeginInvoke is called,that can be used to interact 

    with the delegate as it is pending execution in the event queue.

  

  BeginInvoke(self: Dispatcher,priority: DispatcherPriority,method: Delegate,arg: object) -> DispatcherOperation

  

   Executes the specified delegate asynchronously at the specified priority and with the specified 

    argument on the thread the System.Windows.Threading.Dispatcher is associated with.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   method: A delegate to a method that takes one argument,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   arg: The object to pass as an argument to the specified method.

   Returns: An object,which is returned immediately after 

    erload:System.Windows.Threading.Dispatcher.BeginInvoke is called,that can be used to interact 

    with the delegate as it is pending execution in the event queue.
  """
  pass
 def BeginInvokeShutdown(self,priority):
  """
  BeginInvokeShutdown(self: Dispatcher,priority: DispatcherPriority)

   Initiates shutdown of the System.Windows.Threading.Dispatcher asynchronously.

  

   priority: The priority at which to begin shutting down the dispatcher.
  """
  pass
 def CheckAccess(self):
  """
  CheckAccess(self: Dispatcher) -> bool

  

   Determines whether the calling thread is the thread associated with this 

    System.Windows.Threading.Dispatcher.

  

   Returns: true if the calling thread is the thread associated with this 

    System.Windows.Threading.Dispatcher; otherwise,false.
  """
  pass
 def DisableProcessing(self):
  """
  DisableProcessing(self: Dispatcher) -> DispatcherProcessingDisabled

  

   Disables processing of the System.Windows.Threading.Dispatcher queue.

   Returns: A structure used to re-enable dispatcher processing.
  """
  pass
 @staticmethod
 def ExitAllFrames():
  """
  ExitAllFrames()

   Requests that all frames exit,including nested frames.
  """
  pass
 @staticmethod
 def FromThread(thread):
  """
  FromThread(thread: Thread) -> Dispatcher

  

   Gets the System.Windows.Threading.Dispatcher for the specified thread.

  

   thread: The thread to obtain the System.Windows.Threading.Dispatcher from.

   Returns: The dispatcher for thread.
  """
  pass
 def Invoke(self,*__args):
  """
  Invoke(self: Dispatcher,priority: DispatcherPriority,timeout: TimeSpan,method: Delegate) -> object

  

   Executes the specified delegate synchronously at the specified priority and with the specified 

    time-out value on the thread the System.Windows.Threading.Dispatcher was created.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   timeout: The maximum time to wait for the operation to finish.

   method: The delegate to a method that takes no arguments,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,priority: DispatcherPriority,timeout: TimeSpan,method: Delegate,arg: object) -> object

  

   Executes the specified delegate at the specified priority with the specified argument 

    synchronously on the thread the System.Windows.Threading.Dispatcher is associated with.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   timeout: The maximum time to wait for the operation to finish.

   method: A delegate to a method that takes multiple arguments,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   arg: An object to pass as an argument to the given method. This can be null if no arguments are 

    needed.

  

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,priority: DispatcherPriority,method: Delegate,arg: object) -> object

  

   Executes the specified delegate at the specified priority with the specified argument 

    synchronously on the thread the System.Windows.Threading.Dispatcher is associated with.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   method: A delegate to a method that takes one argument,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   arg: An object to pass as an argument to the given method.

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,priority: DispatcherPriority,method: Delegate,arg: object,*args: Array[object]) -> object

  

   Executes the specified delegate at the specified priority with the specified arguments 

    synchronously on the thread the System.Windows.Threading.Dispatcher is associated with.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   method: A delegate to a method that takes multiple arguments,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   arg: An object to pass as an argument to the given method.

   args: An array of objects to pass as arguments to the given method.

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,priority: DispatcherPriority,timeout: TimeSpan,method: Delegate,arg: object,*args: Array[object]) -> object

  

   Executes the specified delegate at the specified priority with the specified arguments 

    synchronously on the thread the System.Windows.Threading.Dispatcher is associated with.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   timeout: The maximum time to wait for the operation to finish.

   method: A delegate to a method that takes multiple arguments,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   arg: An object to pass as an argument to the specified method.

   args: An array of objects to pass as arguments to the specified method.

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,method: Delegate,timeout: TimeSpan,*args: Array[object]) -> object

  

   Executes the specified delegate within the designated time span at the specified priority with 

    the specified arguments synchronously on the thread the System.Windows.Threading.Dispatcher is 

    associated with.

  

  

   method: A delegate to a method that takes parameters specified in args,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   timeout: The maximum amount of time to wait for the operation to complete.

   args: An array of objects to pass as arguments to the given method. Can be null.

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,method: Delegate,timeout: TimeSpan,priority: DispatcherPriority,*args: Array[object]) -> object

  

   Executes the specified delegate within the designated time span at the specified priority with 

    the specified arguments synchronously on the thread the System.Windows.Threading.Dispatcher is 

    associated with.

  

  

   method: A delegate to a method that takes parameters specified in args,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   timeout: The maximum amount of time to wait for the operation to complete.

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   args: An array of objects to pass as arguments to the given method. Can be null.

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,method: Delegate,*args: Array[object]) -> object

  

   Executes the specified delegate with the specified arguments synchronously on the thread the 

    System.Windows.Threading.Dispatcher is associated with.

  

  

   method: A delegate to a method that takes parameters specified in args,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   args: An array of objects to pass as arguments to the given method. Can be null.

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,method: Delegate,priority: DispatcherPriority,*args: Array[object]) -> object

  

   Executes the specified delegate at the specified priority with the specified arguments 

    synchronously on the thread the System.Windows.Threading.Dispatcher is associated with.

  

  

   method: A delegate to a method that takes parameters specified in args,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   args: An array of objects to pass as arguments to the given method. Can be null.

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke(self: Dispatcher,callback: Action,priority: DispatcherPriority,cancellationToken: CancellationToken)Invoke(self: Dispatcher,callback: Action,priority: DispatcherPriority,cancellationToken: CancellationToken,timeout: TimeSpan)Invoke(self: Dispatcher,callback: Action)Invoke(self: Dispatcher,callback: Action,priority: DispatcherPriority)Invoke[TResult](self: Dispatcher,callback: Func[TResult]) -> TResult

  Invoke[TResult](self: Dispatcher,callback: Func[TResult],priority: DispatcherPriority,cancellationToken: CancellationToken,timeout: TimeSpan) -> TResult

  Invoke(self: Dispatcher,priority: DispatcherPriority,method: Delegate) -> object

  

   Executes the specified delegate synchronously at the specified priority on the thread on which 

    the System.Windows.Threading.Dispatcher is associated with.

  

  

   priority: The priority,relative to the other pending operations in the 

    System.Windows.Threading.Dispatcher event queue,the specified method is invoked.

  

   method: A delegate to a method that takes no arguments,which is pushed onto the 

    System.Windows.Threading.Dispatcher event queue.

  

   Returns: The return value from the delegate being invoked or null if the delegate has no return value.

  Invoke[TResult](self: Dispatcher,callback: Func[TResult],priority: DispatcherPriority) -> TResult

  Invoke[TResult](self: Dispatcher,callback: Func[TResult],priority: DispatcherPriority,cancellationToken: CancellationToken) -> TResult
  """
  pass
 def InvokeAsync(self,callback,priority=None,cancellationToken=None):
  """
  InvokeAsync[TResult](self: Dispatcher,callback: Func[TResult]) -> DispatcherOperation[TResult]

  InvokeAsync[TResult](self: Dispatcher,callback: Func[TResult],priority: DispatcherPriority) -> DispatcherOperation[TResult]

  InvokeAsync[TResult](self: Dispatcher,callback: Func[TResult],priority: DispatcherPriority,cancellationToken: CancellationToken) -> DispatcherOperation[TResult]

  InvokeAsync(self: Dispatcher,callback: Action) -> DispatcherOperation

  InvokeAsync(self: Dispatcher,callback: Action,priority: DispatcherPriority) -> DispatcherOperation

  InvokeAsync(self: Dispatcher,callback: Action,priority: DispatcherPriority,cancellationToken: CancellationToken) -> DispatcherOperation
  """
  pass
 def InvokeShutdown(self):
  """
  InvokeShutdown(self: Dispatcher)

   Initiates the shutdown process of the System.Windows.Threading.Dispatcher synchronously.
  """
  pass
 @staticmethod
 def PushFrame(frame):
  """
  PushFrame(frame: DispatcherFrame)

   Enters an execute loop.

  

   frame: The frame for the dispatcher to process.
  """
  pass
 @staticmethod
 def Run():
  """
  Run()

   Pushes the main execution frame on the event queue of the System.Windows.Threading.Dispatcher.
  """
  pass
 @staticmethod
 def ValidatePriority(priority,parameterName):
  """
  ValidatePriority(priority: DispatcherPriority,parameterName: str)

   Determines whether the specified System.Windows.Threading.DispatcherPriority is a valid priority.

  

   priority: The priority to check.

   parameterName: A string that will be returned by the exception that occurs if the priority is invalid.
  """
  pass
 def VerifyAccess(self):
  """
  VerifyAccess(self: Dispatcher)

   Determines whether the calling thread has access to this System.Windows.Threading.Dispatcher.
  """
  pass
 @staticmethod
 def Yield(priority=None):
  """
  Yield(priority: DispatcherPriority) -> DispatcherPriorityAwaitable

  Yield() -> DispatcherPriorityAwaitable
  """
  pass
 HasShutdownFinished=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Determines whether the System.Windows.Threading.Dispatcher has finished shutting down.



Get: HasShutdownFinished(self: Dispatcher) -> bool



"""

 HasShutdownStarted=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Determines whether the System.Windows.Threading.Dispatcher is shutting down.



Get: HasShutdownStarted(self: Dispatcher) -> bool



"""

 Hooks=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of hooks that provide additional event information about the System.Windows.Threading.Dispatcher.



Get: Hooks(self: Dispatcher) -> DispatcherHooks



"""

 Thread=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the thread this System.Windows.Threading.Dispatcher is associated with.



Get: Thread(self: Dispatcher) -> Thread



"""


 CurrentDispatcher=None
 ShutdownFinished=None
 ShutdownStarted=None
 UnhandledException=None
 UnhandledExceptionFilter=None


class DispatcherEventArgs(EventArgs):
 """ Provides event data for System.Windows.Threading.Dispatcher related events. """
 Dispatcher=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """The System.Windows.Threading.Dispatcher associated with this event.



Get: Dispatcher(self: DispatcherEventArgs) -> Dispatcher



"""



class DispatcherObject(object):
 """ Represents an object that is associated with a System.Windows.Threading.Dispatcher. """
 def CheckAccess(self):
  """
  CheckAccess(self: DispatcherObject) -> bool

  

   Determines whether the calling thread has access to this 

    System.Windows.Threading.DispatcherObject.

  

   Returns: true if the calling thread has access to this object; otherwise,false.
  """
  pass
 def VerifyAccess(self):
  """
  VerifyAccess(self: DispatcherObject)

   Enforces that the calling thread has access to this System.Windows.Threading.DispatcherObject.
  """
  pass
 Dispatcher=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Threading.Dispatcher this System.Windows.Threading.DispatcherObject is associated with.



Get: Dispatcher(self: DispatcherObject) -> Dispatcher



"""



class DispatcherFrame(DispatcherObject):
 """
 Represents an execution loop in the System.Windows.Threading.Dispatcher.

 

 DispatcherFrame()

 DispatcherFrame(exitWhenRequested: bool)
 """
 @staticmethod
 def __new__(self,exitWhenRequested=None):
  """
  __new__(cls: type)

  __new__(cls: type,exitWhenRequested: bool)
  """
  pass
 Continue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether this System.Windows.Threading.DispatcherFrame should continue.



Get: Continue(self: DispatcherFrame) -> bool



Set: Continue(self: DispatcherFrame)=value

"""



class DispatcherHookEventArgs(EventArgs):
 """
 Provides event data for System.Windows.Threading.DispatcherHooks events.

 

 DispatcherHookEventArgs(operation: DispatcherOperation)
 """
 @staticmethod
 def __new__(self,operation):
  """ __new__(cls: type,operation: DispatcherOperation) """
  pass
 Dispatcher=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Threading.Dispatcher associated with this event.



Get: Dispatcher(self: DispatcherHookEventArgs) -> Dispatcher



"""

 Operation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Threading.DispatcherOperation associated with this event.



Get: Operation(self: DispatcherHookEventArgs) -> DispatcherOperation



"""



class DispatcherHookEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle System.Windows.Threading.DispatcherHooks related events.

 

 DispatcherHookEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: DispatcherHookEventHandler,sender: object,e: DispatcherHookEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: DispatcherHookEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: DispatcherHookEventHandler,sender: object,e: DispatcherHookEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class DispatcherHooks(object):
 """ Provides additional event information about System.Windows.Threading.Dispatcher processing. """
 DispatcherInactive=None
 OperationAborted=None
 OperationCompleted=None
 OperationPosted=None
 OperationPriorityChanged=None
 OperationStarted=None


class DispatcherOperationCallback(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents a delegate to use for dispatcher operations.

 

 DispatcherOperationCallback(object: object,method: IntPtr)
 """
 def BeginInvoke(self,arg,callback,object):
  """ BeginInvoke(self: DispatcherOperationCallback,arg: object,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: DispatcherOperationCallback,result: IAsyncResult) -> object """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,arg):
  """ Invoke(self: DispatcherOperationCallback,arg: object) -> object """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class DispatcherOperationStatus(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the possible values for the status of a System.Windows.Threading.DispatcherOperation.

 

 enum DispatcherOperationStatus,values: Aborted (1),Completed (2),Executing (3),Pending (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Aborted=None
 Completed=None
 Executing=None
 Pending=None
 value__=None


class DispatcherPriority(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the priorities at which operations can be invoked by way of the System.Windows.Threading.Dispatcher.

 

 enum DispatcherPriority,values: ApplicationIdle (2),Background (4),ContextIdle (3),DataBind (8),Inactive (0),Input (5),Invalid (-1),Loaded (6),Normal (9),Render (7),Send (10),SystemIdle (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ApplicationIdle=None
 Background=None
 ContextIdle=None
 DataBind=None
 Inactive=None
 Input=None
 Invalid=None
 Loaded=None
 Normal=None
 Render=None
 Send=None
 SystemIdle=None
 value__=None


class DispatcherPriorityAwaitable(object):
 # no doc
 def GetAwaiter(self):
  """ GetAwaiter(self: DispatcherPriorityAwaitable) -> DispatcherPriorityAwaiter """
  pass

class DispatcherPriorityAwaiter(object,INotifyCompletion):
 # no doc
 def GetResult(self):
  """ GetResult(self: DispatcherPriorityAwaiter) """
  pass
 def OnCompleted(self,continuation):
  """ OnCompleted(self: DispatcherPriorityAwaiter,continuation: Action) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 IsCompleted=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsCompleted(self: DispatcherPriorityAwaiter) -> bool



"""



class DispatcherProcessingDisabled(object,IDisposable):
 """ Represents the Dispatcher when it is in a disable state and provides a means to re-enable dispatcher processing. """
 def Dispose(self):
  """
  Dispose(self: DispatcherProcessingDisabled)

   Re-enables dispatcher processing.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: DispatcherProcessingDisabled,obj: object) -> bool

  

   Determines whether the specified System.Windows.Threading.DispatcherProcessingDisabled object is 

    equal to this System.Windows.Threading.DispatcherProcessingDisabled object.

  

  

   obj: The object to evaluate for equality.

   Returns: true if the specified object is equal to this 

    System.Windows.Threading.DispatcherProcessingDisabled object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DispatcherProcessingDisabled) -> int

  

   Gets a hash code for this instance.

   Returns: A signed 32-bit integer hash code.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __ne__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass

class DispatcherSynchronizationContext(SynchronizationContext):
 """
 Provides a synchronization context for Windows Presentation Foundation (WPF).

 

 DispatcherSynchronizationContext()

 DispatcherSynchronizationContext(dispatcher: Dispatcher)

 DispatcherSynchronizationContext(dispatcher: Dispatcher,priority: DispatcherPriority)
 """
 def CreateCopy(self):
  """
  CreateCopy(self: DispatcherSynchronizationContext) -> SynchronizationContext

  

   Creates a copy of this System.Windows.Threading.DispatcherSynchronizationContext.

   Returns: The copy of this synchronization context.
  """
  pass
 def Post(self,d,state):
  """
  Post(self: DispatcherSynchronizationContext,d: SendOrPostCallback,state: object)

   Invokes the callback in the synchronization context asynchronously.

  

   d: The delegate to call.

   state: The object passed to the delegate.
  """
  pass
 def Send(self,d,state):
  """
  Send(self: DispatcherSynchronizationContext,d: SendOrPostCallback,state: object)

   Invokes the callback in the synchronization context synchronously.

  

   d: The delegate to call.

   state: The object passed to the delegate.
  """
  pass
 def Wait(self,waitHandles,waitAll,millisecondsTimeout):
  """
  Wait(self: DispatcherSynchronizationContext,waitHandles: Array[IntPtr],waitAll: bool,millisecondsTimeout: int) -> int

  

   Waits for any or all the elements in the specified array to receive a signal.

  

   waitHandles: An array that contains the native operating system handles.

   waitAll: true to wait for all handles; false to wait for any handle.

   millisecondsTimeout: The number of milliseconds to wait,or System.Threading.Timeout.Infinite (-1) to wait 

    indefinitely.

  

   Returns: The array index of the object that satisfied the wait.
  """
  pass
 @staticmethod
 def __new__(self,dispatcher=None,priority=None):
  """
  __new__(cls: type)

  __new__(cls: type,dispatcher: Dispatcher)

  __new__(cls: type,dispatcher: Dispatcher,priority: DispatcherPriority)
  """
  pass

class DispatcherTimer(object):
 """
 A timer that is integrated into the System.Windows.Threading.Dispatcher queue which is processed at a specified interval of time and at a specified priority.

 

 DispatcherTimer()

 DispatcherTimer(priority: DispatcherPriority)

 DispatcherTimer(priority: DispatcherPriority,dispatcher: Dispatcher)

 DispatcherTimer(interval: TimeSpan,priority: DispatcherPriority,callback: EventHandler,dispatcher: Dispatcher)
 """
 def Start(self):
  """
  Start(self: DispatcherTimer)

   Starts the System.Windows.Threading.DispatcherTimer.
  """
  pass
 def Stop(self):
  """
  Stop(self: DispatcherTimer)

   Stops the System.Windows.Threading.DispatcherTimer.
  """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,priority: DispatcherPriority)

  __new__(cls: type,priority: DispatcherPriority,dispatcher: Dispatcher)

  __new__(cls: type,interval: TimeSpan,priority: DispatcherPriority,callback: EventHandler,dispatcher: Dispatcher)
  """
  pass
 Dispatcher=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Threading.Dispatcher associated with this System.Windows.Threading.DispatcherTimer.



Get: Dispatcher(self: DispatcherTimer) -> Dispatcher



"""

 Interval=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the period of time between timer ticks.



Get: Interval(self: DispatcherTimer) -> TimeSpan



Set: Interval(self: DispatcherTimer)=value

"""

 IsEnabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the timer is running.



Get: IsEnabled(self: DispatcherTimer) -> bool



Set: IsEnabled(self: DispatcherTimer)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a user-defined data object.



Get: Tag(self: DispatcherTimer) -> object



Set: Tag(self: DispatcherTimer)=value

"""


 Tick=None


class DispatcherUnhandledExceptionEventArgs(DispatcherEventArgs):
 """ Provides data for the System.Windows.Threading.Dispatcher�System.Windows.Threading.Dispatcher.UnhandledException event. """
 Exception=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the exception that was raised when executing code by way of the dispatcher.



Get: Exception(self: DispatcherUnhandledExceptionEventArgs) -> Exception



"""

 Handled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the exception event has been handled.



Get: Handled(self: DispatcherUnhandledExceptionEventArgs) -> bool



Set: Handled(self: DispatcherUnhandledExceptionEventArgs)=value

"""



class DispatcherUnhandledExceptionEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.Windows.Threading.Dispatcher.UnhandledException event.

 

 DispatcherUnhandledExceptionEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: DispatcherUnhandledExceptionEventHandler,sender: object,e: DispatcherUnhandledExceptionEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: DispatcherUnhandledExceptionEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: DispatcherUnhandledExceptionEventHandler,sender: object,e: DispatcherUnhandledExceptionEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class DispatcherUnhandledExceptionFilterEventArgs(DispatcherEventArgs):
 """ Provides data for the System.Windows.Threading.Dispatcher�System.Windows.Threading.Dispatcher.UnhandledExceptionFilter event. """
 Exception=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the exception that was raised when executing code by way of the dispatcher.



Get: Exception(self: DispatcherUnhandledExceptionFilterEventArgs) -> Exception



"""

 RequestCatch=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the exception should be caught and the event handlers called.



Get: RequestCatch(self: DispatcherUnhandledExceptionFilterEventArgs) -> bool



Set: RequestCatch(self: DispatcherUnhandledExceptionFilterEventArgs)=value

"""



class DispatcherUnhandledExceptionFilterEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.Windows.Threading.Dispatcher.UnhandledExceptionFilter event.

 

 DispatcherUnhandledExceptionFilterEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: DispatcherUnhandledExceptionFilterEventHandler,sender: object,e: DispatcherUnhandledExceptionFilterEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: DispatcherUnhandledExceptionFilterEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: DispatcherUnhandledExceptionFilterEventHandler,sender: object,e: DispatcherUnhandledExceptionFilterEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass




class ISupportInitialize:
 """ Specifies that this object supports a simple,transacted notification for batch initialization. """
 def BeginInit(self):
  """
  BeginInit(self: ISupportInitialize)

   Signals the object that initialization is starting.
  """
  pass
 def EndInit(self):
  """
  EndInit(self: ISupportInitialize)

   Signals the object that initialization is complete.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class DateTime(object,IComparable,IFormattable,IConvertible,ISerializable,IComparable[DateTime],IEquatable[DateTime]):
 """
 Represents an instant in time,typically expressed as a date and time of day.

 

 DateTime(ticks: Int64)

 DateTime(ticks: Int64,kind: DateTimeKind)

 DateTime(year: int,month: int,day: int)

 DateTime(year: int,month: int,day: int,calendar: Calendar)

 DateTime(year: int,month: int,day: int,hour: int,minute: int,second: int)

 DateTime(year: int,month: int,day: int,hour: int,minute: int,second: int,kind: DateTimeKind)

 DateTime(year: int,month: int,day: int,hour: int,minute: int,second: int,calendar: Calendar)

 DateTime(year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int)

 DateTime(year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,kind: DateTimeKind)

 DateTime(year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,calendar: Calendar)

 DateTime(year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,calendar: Calendar,kind: DateTimeKind)
 """
 def Add(self,value):
  """
  Add(self: DateTime,value: TimeSpan) -> DateTime

  

   Returns a new System.DateTime that adds the value of the specified System.TimeSpan to the value 

    of this instance.

  

  

   value: A positive or negative time interval.

   Returns: An object whose value is the sum of the date and time represented by this instance and the time 

    interval represented by value.
  """
  pass
 def AddDays(self,value):
  """
  AddDays(self: DateTime,value: float) -> DateTime

  

   Returns a new System.DateTime that adds the specified number of days to the value of this 

    instance.

  

  

   value: A number of whole and fractional days. The value parameter can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by this instance and the 

    number of days represented by value.
  """
  pass
 def AddHours(self,value):
  """
  AddHours(self: DateTime,value: float) -> DateTime

  

   Returns a new System.DateTime that adds the specified number of hours to the value of this 

    instance.

  

  

   value: A number of whole and fractional hours. The value parameter can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by this instance and the 

    number of hours represented by value.
  """
  pass
 def AddMilliseconds(self,value):
  """
  AddMilliseconds(self: DateTime,value: float) -> DateTime

  

   Returns a new System.DateTime that adds the specified number of milliseconds to the value of 

    this instance.

  

  

   value: A number of whole and fractional milliseconds. The value parameter can be negative or positive. 

    Note that this value is rounded to the nearest integer.

  

   Returns: An object whose value is the sum of the date and time represented by this instance and the 

    number of milliseconds represented by value.
  """
  pass
 def AddMinutes(self,value):
  """
  AddMinutes(self: DateTime,value: float) -> DateTime

  

   Returns a new System.DateTime that adds the specified number of minutes to the value of this 

    instance.

  

  

   value: A number of whole and fractional minutes. The value parameter can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by this instance and the 

    number of minutes represented by value.
  """
  pass
 def AddMonths(self,months):
  """
  AddMonths(self: DateTime,months: int) -> DateTime

  

   Returns a new System.DateTime that adds the specified number of months to the value of this 

    instance.

  

  

   months: A number of months. The months parameter can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by this instance and months.
  """
  pass
 def AddSeconds(self,value):
  """
  AddSeconds(self: DateTime,value: float) -> DateTime

  

   Returns a new System.DateTime that adds the specified number of seconds to the value of this 

    instance.

  

  

   value: A number of whole and fractional seconds. The value parameter can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by this instance and the 

    number of seconds represented by value.
  """
  pass
 def AddTicks(self,value):
  """
  AddTicks(self: DateTime,value: Int64) -> DateTime

  

   Returns a new System.DateTime that adds the specified number of ticks to the value of this 

    instance.

  

  

   value: A number of 100-nanosecond ticks. The value parameter can be positive or negative.

   Returns: An object whose value is the sum of the date and time represented by this instance and the time 

    represented by value.
  """
  pass
 def AddYears(self,value):
  """
  AddYears(self: DateTime,value: int) -> DateTime

  

   Returns a new System.DateTime that adds the specified number of years to the value of this 

    instance.

  

  

   value: A number of years. The value parameter can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by this instance and the 

    number of years represented by value.
  """
  pass
 @staticmethod
 def Compare(t1,t2):
  """
  Compare(t1: DateTime,t2: DateTime) -> int

  

   Compares two instances of System.DateTime and returns an integer that indicates whether the 

    first instance is earlier than,the same as,or later than the second instance.

  

  

   t1: The first object to compare.

   t2: The second object to compare.

   Returns: A signed number indicating the relative values of t1 and t2.Value Type Condition Less than zero 

    t1 is earlier than t2. Zero t1 is the same as t2. Greater than zero t1 is later than t2.
  """
  pass
 def CompareTo(self,value):
  """
  CompareTo(self: DateTime,value: DateTime) -> int

  

   Compares the value of this instance to a specified System.DateTime value and returns an integer 

    that indicates whether this instance is earlier than,the same as,or later than the specified 

    System.DateTime value.

  

  

   value: The object to compare to the current instance.

   Returns: A signed number indicating the relative values of this instance and the value parameter.Value 

    Description Less than zero This instance is earlier than value. Zero This instance is the same 

    as value. Greater than zero This instance is later than value.

  

  CompareTo(self: DateTime,value: object) -> int

  

   Compares the value of this instance to a specified object that contains a specified 

    System.DateTime value,and returns an integer that indicates whether this instance is earlier 

    than,the same as,or later than the specified System.DateTime value.

  

  

   value: A boxed object to compare,or null.

   Returns: A signed number indicating the relative values of this instance and value.Value Description Less 

    than zero This instance is earlier than value. Zero This instance is the same as value. Greater 

    than zero This instance is later than value,or value is null.
  """
  pass
 @staticmethod
 def DaysInMonth(year,month):
  """
  DaysInMonth(year: int,month: int) -> int

  

   Returns the number of days in the specified month and year.

  

   year: The year.

   month: The month (a number ranging from 1 to 12).

   Returns: The number of days in month for the specified year.For example,if month equals 2 for February,

    the return value is 28 or 29 depending upon whether year is a leap year.
  """
  pass
 def Equals(self,*__args):
  """
  Equals(t1: DateTime,t2: DateTime) -> bool

  

   Returns a value indicating whether two System.DateTime instances have the same date and time 

    value.

  

  

   t1: The first object to compare.

   t2: The second object to compare.

   Returns: true if the two values are equal; otherwise,false.

  Equals(self: DateTime,value: DateTime) -> bool

  

   Returns a value indicating whether the value of this instance is equal to the value of the 

    specified System.DateTime instance.

  

  

   value: The object to compare to this instance.

   Returns: true if the value parameter equals the value of this instance; otherwise,false.

  Equals(self: DateTime,value: object) -> bool

  

   Returns a value indicating whether this instance is equal to a specified object.

  

   value: The object to compare to this instance.

   Returns: true if value is an instance of System.DateTime and equals the value of this instance; 

    otherwise,false.
  """
  pass
 @staticmethod
 def FromBinary(dateData):
  """
  FromBinary(dateData: Int64) -> DateTime

  

   Deserializes a 64-bit binary value and recreates an original serialized System.DateTime object.

  

   dateData: A 64-bit signed integer that encodes the System.DateTime.Kind property in a 2-bit field and the 

    System.DateTime.Ticks property in a 62-bit field.

  

   Returns: An object that is equivalent to the System.DateTime object that was serialized by the 

    System.DateTime.ToBinary method.
  """
  pass
 @staticmethod
 def FromFileTime(fileTime):
  """
  FromFileTime(fileTime: Int64) -> DateTime

  

   Converts the specified Windows file time to an equivalent local time.

  

   fileTime: A Windows file time expressed in ticks.

   Returns: An object that represents the local time equivalent of the date and time represented by the 

    fileTime parameter.
  """
  pass
 @staticmethod
 def FromFileTimeUtc(fileTime):
  """
  FromFileTimeUtc(fileTime: Int64) -> DateTime

  

   Converts the specified Windows file time to an equivalent UTC time.

  

   fileTime: A Windows file time expressed in ticks.

   Returns: An object that represents the UTC time equivalent of the date and time represented by the 

    fileTime parameter.
  """
  pass
 @staticmethod
 def FromOADate(d):
  """
  FromOADate(d: float) -> DateTime

  

   Returns a System.DateTime equivalent to the specified OLE Automation Date.

  

   d: An OLE Automation Date value.

   Returns: An object that represents the same date and time as d.
  """
  pass
 def GetDateTimeFormats(self,*__args):
  """
  GetDateTimeFormats(self: DateTime,format: Char) -> Array[str]

  

   Converts the value of this instance to all the string representations supported by the specified 

    standard date and time format specifier.

  

  

   format: A standard date and time format string (see Remarks).

   Returns: A string array where each element is the representation of the value of this instance formatted 

    with the format standard date and time format specifier.

  

  GetDateTimeFormats(self: DateTime,format: Char,provider: IFormatProvider) -> Array[str]

  

   Converts the value of this instance to all the string representations supported by the specified 

    standard date and time format specifier and culture-specific formatting information.

  

  

   format: A date and time format string (see Remarks).

   provider: An object that supplies culture-specific formatting information about this instance.

   Returns: A string array where each element is the representation of the value of this instance formatted 

    with one of the standard date and time format specifiers.

  

  GetDateTimeFormats(self: DateTime) -> Array[str]

  

   Converts the value of this instance to all the string representations supported by the standard 

    date and time format specifiers.

  

   Returns: A string array where each element is the representation of the value of this instance formatted 

    with one of the standard date and time format specifiers.

  

  GetDateTimeFormats(self: DateTime,provider: IFormatProvider) -> Array[str]

  

   Converts the value of this instance to all the string representations supported by the standard 

    date and time format specifiers and the specified culture-specific formatting information.

  

  

   provider: An object that supplies culture-specific formatting information about this instance.

   Returns: A string array where each element is the representation of the value of this instance formatted 

    with one of the standard date and time format specifiers.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DateTime) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def GetTypeCode(self):
  """
  GetTypeCode(self: DateTime) -> TypeCode

  

   Returns the System.TypeCode for value type System.DateTime.

   Returns: The enumerated constant,System.TypeCode.DateTime.
  """
  pass
 def IsDaylightSavingTime(self):
  """
  IsDaylightSavingTime(self: DateTime) -> bool

  

   Indicates whether this instance of System.DateTime is within the daylight saving time range for 

    the current time zone.

  

   Returns: true if System.DateTime.Kind is System.DateTimeKind.Local or System.DateTimeKind.Unspecified and 

    the value of this instance of System.DateTime is within the daylight saving time range for the 

    current time zone. false if System.DateTime.Kind is System.DateTimeKind.Utc.
  """
  pass
 @staticmethod
 def IsLeapYear(year):
  """
  IsLeapYear(year: int) -> bool

  

   Returns an indication whether the specified year is a leap year.

  

   year: A 4-digit year.

   Returns: true if year is a leap year; otherwise,false.
  """
  pass
 @staticmethod
 def Parse(s,provider=None,styles=None):
  """
  Parse(s: str,provider: IFormatProvider,styles: DateTimeStyles) -> DateTime

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent using the specified culture-specific format information and formatting style.

  

  

   s: A string containing a date and time to convert.

   provider: An object that supplies culture-specific formatting information about s.

   styles: A bitwise combination of the enumeration values that indicates the style elements that can be 

    present in s for the parse operation to succeed and that defines how to interpret the parsed 

    date in relation to the current time zone or the current date. A typical value to specify is 

    System.Globalization.DateTimeStyles.None.

  

   Returns: An object that is equivalent to the date and time contained in s,as specified by provider and 

    styles.

  

  Parse(s: str,provider: IFormatProvider) -> DateTime

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent using the specified culture-specific format information.

  

  

   s: A string containing a date and time to convert.

   provider: An object that supplies culture-specific format information about s.

   Returns: An object that is equivalent to the date and time contained in s as specified by provider.

  Parse(s: str) -> DateTime

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent.

  

  

   s: A string containing a date and time to convert.

   Returns: An object that is equivalent to the date and time contained in s.
  """
  pass
 @staticmethod
 def ParseExact(s,*__args):
  """
  ParseExact(s: str,formats: Array[str],provider: IFormatProvider,style: DateTimeStyles) -> DateTime

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent using the specified array of formats,culture-specific format information,and style. 

    The format of the string representation must match at least one of the specified formats exactly 

    or an exception is thrown.

  

  

   s: A string containing one or more dates and times to convert.

   formats: An array of allowable formats of s.

   provider: An object that supplies culture-specific format information about s.

   style: A bitwise combination of enumeration values that indicates the permitted format of s. A typical 

    value to specify is System.Globalization.DateTimeStyles.None.

  

   Returns: An object that is equivalent to the date and time contained in s,as specified by formats,

    provider,and style.

  

  ParseExact(s: str,format: str,provider: IFormatProvider,style: DateTimeStyles) -> DateTime

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent using the specified format,culture-specific format information,and style. The 

    format of the string representation must match the specified format exactly or an exception is 

    thrown.

  

  

   s: A string containing a date and time to convert.

   format: A format specifier that defines the required format of s.

   provider: An object that supplies culture-specific formatting information about s.

   style: A bitwise combination of the enumeration values that provides additional information about s,

    about style elements that may be present in s,or about the conversion from s to a 

    System.DateTime value. A typical value to specify is System.Globalization.DateTimeStyles.None.

  

   Returns: An object that is equivalent to the date and time contained in s,as specified by format,

    provider,and style.

  

  ParseExact(s: str,format: str,provider: IFormatProvider) -> DateTime

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent using the specified format and culture-specific format information. The format of the 

    string representation must match the specified format exactly.

  

  

   s: A string that contains a date and time to convert.

   format: A format specifier that defines the required format of s.

   provider: An object that supplies culture-specific format information about s.

   Returns: An object that is equivalent to the date and time contained in s,as specified by format and 

    provider.
  """
  pass
 @staticmethod
 def SpecifyKind(value,kind):
  """
  SpecifyKind(value: DateTime,kind: DateTimeKind) -> DateTime

  

   Creates a new System.DateTime object that has the same number of ticks as the specified 

    System.DateTime,but is designated as either local time,Coordinated Universal Time (UTC),or 

    neither,as indicated by the specified System.DateTimeKind value.

  

  

   value: A date and time.

   kind: One of the enumeration values that indicates whether the new object represents local time,UTC,

    or neither.

  

   Returns: A new object that has the same number of ticks as the object represented by the value parameter 

    and the System.DateTimeKind value specified by the kind parameter.
  """
  pass
 def Subtract(self,value):
  """
  Subtract(self: DateTime,value: TimeSpan) -> DateTime

  

   Subtracts the specified duration from this instance.

  

   value: The time interval to subtract.

   Returns: An object that is equal to the date and time represented by this instance minus the time 

    interval represented by value.

  

  Subtract(self: DateTime,value: DateTime) -> TimeSpan

  

   Subtracts the specified date and time from this instance.

  

   value: The date and time value to subtract.

   Returns: A time interval that is equal to the date and time represented by this instance minus the date 

    and time represented by value.
  """
  pass
 def ToBinary(self):
  """
  ToBinary(self: DateTime) -> Int64

  

   Serializes the current System.DateTime object to a 64-bit binary value that subsequently can be 

    used to recreate the System.DateTime object.

  

   Returns: A 64-bit signed integer that encodes the System.DateTime.Kind and System.DateTime.Ticks 

    properties.
  """
  pass
 def ToFileTime(self):
  """
  ToFileTime(self: DateTime) -> Int64

  

   Converts the value of the current System.DateTime object to a Windows file time.

   Returns: The value of the current System.DateTime object expressed as a Windows file time.
  """
  pass
 def ToFileTimeUtc(self):
  """
  ToFileTimeUtc(self: DateTime) -> Int64

  

   Converts the value of the current System.DateTime object to a Windows file time.

   Returns: The value of the current System.DateTime object expressed as a Windows file time.
  """
  pass
 def ToLocalTime(self):
  """
  ToLocalTime(self: DateTime) -> DateTime

  

   Converts the value of the current System.DateTime object to local time.

   Returns: An object whose System.DateTime.Kind property is System.DateTimeKind.Local,and whose value is 

    the local time equivalent to the value of the current System.DateTime object,or 

    System.DateTime.MaxValue if the converted value is too large to be represented by a 

    System.DateTime object,or System.DateTime.MinValue if the converted value is too small to be 

    represented as a System.DateTime object.
  """
  pass
 def ToLongDateString(self):
  """
  ToLongDateString(self: DateTime) -> str

  

   Converts the value of the current System.DateTime object to its equivalent long date string 

    representation.

  

   Returns: A string that contains the long date string representation of the current System.DateTime object.
  """
  pass
 def ToLongTimeString(self):
  """
  ToLongTimeString(self: DateTime) -> str

  

   Converts the value of the current System.DateTime object to its equivalent long time string 

    representation.

  

   Returns: A string that contains the long time string representation of the current System.DateTime object.
  """
  pass
 def ToOADate(self):
  """
  ToOADate(self: DateTime) -> float

  

   Converts the value of this instance to the equivalent OLE Automation date.

   Returns: A double-precision floating-point number that contains an OLE Automation date equivalent to the 

    value of this instance.
  """
  pass
 def ToShortDateString(self):
  """
  ToShortDateString(self: DateTime) -> str

  

   Converts the value of the current System.DateTime object to its equivalent short date string 

    representation.

  

   Returns: A string that contains the short date string representation of the current System.DateTime 

    object.
  """
  pass
 def ToShortTimeString(self):
  """
  ToShortTimeString(self: DateTime) -> str

  

   Converts the value of the current System.DateTime object to its equivalent short time string 

    representation.

  

   Returns: A string that contains the short time string representation of the current System.DateTime 

    object.
  """
  pass
 def ToString(self,*__args):
  """
  ToString(self: DateTime,provider: IFormatProvider) -> str

  

   Converts the value of the current System.DateTime object to its equivalent string representation 

    using the specified culture-specific format information.

  

  

   provider: An object that supplies culture-specific formatting information.

   Returns: A string representation of value of the current System.DateTime object as specified by provider.

  ToString(self: DateTime,format: str,provider: IFormatProvider) -> str

  

   Converts the value of the current System.DateTime object to its equivalent string representation 

    using the specified format and culture-specific format information.

  

  

   format: A standard or custom date and time format string.

   provider: An object that supplies culture-specific formatting information.

   Returns: A string representation of value of the current System.DateTime object as specified by format 

    and provider.

  

  ToString(self: DateTime) -> str

  

   Converts the value of the current System.DateTime object to its equivalent string representation.

   Returns: A string representation of the value of the current System.DateTime object.

  ToString(self: DateTime,format: str) -> str

  

   Converts the value of the current System.DateTime object to its equivalent string representation 

    using the specified format.

  

  

   format: A standard or custom date and time format string (see Remarks).

   Returns: A string representation of value of the current System.DateTime object as specified by format.
  """
  pass
 def ToUniversalTime(self):
  """
  ToUniversalTime(self: DateTime) -> DateTime

  

   Converts the value of the current System.DateTime object to Coordinated Universal Time (UTC).

   Returns: An object whose System.DateTime.Kind property is System.DateTimeKind.Utc,and whose value is the 

    UTC equivalent to the value of the current System.DateTime object,or System.DateTime.MaxValue 

    if the converted value is too large to be represented by a System.DateTime object,or 

    System.DateTime.MinValue if the converted value is too small to be represented by a 

    System.DateTime object.
  """
  pass
 @staticmethod
 def TryParse(s,*__args):
  """
  TryParse(s: str,provider: IFormatProvider,styles: DateTimeStyles) -> (bool,DateTime)

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent using the specified culture-specific format information and formatting style,and 

    returns a value that indicates whether the conversion succeeded.

  

  

   s: A string containing a date and time to convert.

   provider: An object that supplies culture-specific formatting information about s.

   styles: A bitwise combination of enumeration values that defines how to interpret the parsed date in 

    relation to the current time zone or the current date. A typical value to specify is 

    System.Globalization.DateTimeStyles.None.

  

   Returns: true if the s parameter was converted successfully; otherwise,false.

  TryParse(s: str) -> (bool,DateTime)

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent and returns a value that indicates whether the conversion succeeded.

  

  

   s: A string containing a date and time to convert.

   Returns: true if the s parameter was converted successfully; otherwise,false.
  """
  pass
 @staticmethod
 def TryParseExact(s,*__args):
  """
  TryParseExact(s: str,formats: Array[str],provider: IFormatProvider,style: DateTimeStyles) -> (bool,DateTime)

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent using the specified array of formats,culture-specific format information,and style. 

    The format of the string representation must match at least one of the specified formats 

    exactly. The method returns a value that indicates whether the conversion succeeded.

  

  

   s: A string containing one or more dates and times to convert.

   formats: An array of allowable formats of s.

   provider: An object that supplies culture-specific format information about s.

   style: A bitwise combination of enumeration values that indicates the permitted format of s. A typical 

    value to specify is System.Globalization.DateTimeStyles.None.

  

   Returns: true if the s parameter was converted successfully; otherwise,false.

  TryParseExact(s: str,format: str,provider: IFormatProvider,style: DateTimeStyles) -> (bool,DateTime)

  

   Converts the specified string representation of a date and time to its System.DateTime 

    equivalent using the specified format,culture-specific format information,and style. The 

    format of the string representation must match the specified format exactly. The method returns 

    a value that indicates whether the conversion succeeded.

  

  

   s: A string containing a date and time to convert.

   format: The required format of s.

   provider: An object that supplies culture-specific formatting information about s.

   style: A bitwise combination of one or more enumeration values that indicate the permitted format of s.

   Returns: true if s was converted successfully; otherwise,false.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __cmp__(self,*args):
  """ x.__cmp__(y) <==> cmp(x,y) """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,ticks: Int64)

  __new__(cls: type,ticks: Int64,kind: DateTimeKind)

  __new__(cls: type,year: int,month: int,day: int)

  __new__(cls: type,year: int,month: int,day: int,calendar: Calendar)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,kind: DateTimeKind)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,calendar: Calendar)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,kind: DateTimeKind)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,calendar: Calendar)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,calendar: Calendar,kind: DateTimeKind)

  __new__[DateTime]() -> DateTime
  """
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __rsub__(self,*args):
  """
  __rsub__(d1: DateTime,d2: DateTime) -> TimeSpan

  

   Subtracts a specified date and time from another specified date and time and returns a time 

    interval.

  

  

   d1: The date and time value to subtract from (the minuend).

   d2: The date and time value to subtract (the subtrahend).

   Returns: The time interval between d1 and d2; that is,d1 minus d2.
  """
  pass
 def __str__(self,*args):
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-yx.__sub__(y) <==> x-y """
  pass
 Date=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the date component of this instance.



Get: Date(self: DateTime) -> DateTime



"""

 Day=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the day of the month represented by this instance.



Get: Day(self: DateTime) -> int



"""

 DayOfWeek=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the day of the week represented by this instance.



Get: DayOfWeek(self: DateTime) -> DayOfWeek



"""

 DayOfYear=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the day of the year represented by this instance.



Get: DayOfYear(self: DateTime) -> int



"""

 Hour=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the hour component of the date represented by this instance.



Get: Hour(self: DateTime) -> int



"""

 Kind=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the time represented by this instance is based on local time,Coordinated Universal Time (UTC),or neither.



Get: Kind(self: DateTime) -> DateTimeKind



"""

 Millisecond=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the milliseconds component of the date represented by this instance.



Get: Millisecond(self: DateTime) -> int



"""

 Minute=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the minute component of the date represented by this instance.



Get: Minute(self: DateTime) -> int



"""

 Month=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the month component of the date represented by this instance.



Get: Month(self: DateTime) -> int



"""

 Second=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the seconds component of the date represented by this instance.



Get: Second(self: DateTime) -> int



"""

 Ticks=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of ticks that represent the date and time of this instance.



Get: Ticks(self: DateTime) -> Int64



"""

 TimeOfDay=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the time of day for this instance.



Get: TimeOfDay(self: DateTime) -> TimeSpan



"""

 Year=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the year component of the date represented by this instance.



Get: Year(self: DateTime) -> int



"""


 MaxValue=None
 MinValue=None
 Now=None
 Today=None
 UtcNow=None




class TraceSwitch(Switch):
 """
 Provides a multilevel switch to control tracing and debug output without recompiling your code.

 

 TraceSwitch(displayName: str,description: str)

 TraceSwitch(displayName: str,description: str,defaultSwitchValue: str)
 """
 @staticmethod
 def __new__(self,displayName,description,defaultSwitchValue=None):
  """
  __new__(cls: type,displayName: str,description: str)

  __new__(cls: type,displayName: str,description: str,defaultSwitchValue: str)
  """
  pass
 Level=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the trace level that determines the messages the switch allows.



Get: Level(self: TraceSwitch) -> TraceLevel



Set: Level(self: TraceSwitch)=value

"""

 SwitchSetting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the current setting for this switch.



"""

 TraceError=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the switch allows error-handling messages.



Get: TraceError(self: TraceSwitch) -> bool



"""

 TraceInfo=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the switch allows informational messages.



Get: TraceInfo(self: TraceSwitch) -> bool



"""

 TraceVerbose=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the switch allows all messages.



Get: TraceVerbose(self: TraceSwitch) -> bool



"""

 TraceWarning=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the switch allows warning messages.



Get: TraceWarning(self: TraceSwitch) -> bool



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the switch.



"""





class FileSystemEventArgs(EventArgs):
 """
 Provides data for the directory events: System.IO.FileSystemWatcher.Changed,System.IO.FileSystemWatcher.Created,System.IO.FileSystemWatcher.Deleted.

 

 FileSystemEventArgs(changeType: WatcherChangeTypes,directory: str,name: str)
 """
 @staticmethod
 def __new__(self,changeType,directory,name):
  """ __new__(cls: type,changeType: WatcherChangeTypes,directory: str,name: str) """
  pass
 ChangeType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type of directory event that occurred.



Get: ChangeType(self: FileSystemEventArgs) -> WatcherChangeTypes



"""

 FullPath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the fully qualifed path of the affected file or directory.



Get: FullPath(self: FileSystemEventArgs) -> str



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the affected file or directory.



Get: Name(self: FileSystemEventArgs) -> str



"""


